@@ -164,8 +164,7 @@ def get_tf_callbacks(root,
         if x_test is not None and y_test is not None:
             callbacks_.append(ConfuseCallback(x_test, y_test,
                                               file_writer,
-                                              label_names=label_info,
-                                              y_argmax=y_argmax,
+                                              class_names=label_info,
                                               figure_size=figure_size)
                               )
 
