@@ -14,10 +14,16 @@ def get_transfer_learning_model(target_model=tf.keras.applications.VGG19,
     if base_model_only:
         return base_model_
 
-    model_ = tf.keras.Sequential(base_model_.layers + [
-        tf.keras.layers.Flatten(),
-        tf.keras.layers.Dense(n_class, activation='softmax')
-    ])
+    try:
+        model_ = tf.keras.Sequential(base_model_.layers + [
+            tf.keras.layers.Flatten(),
+            tf.keras.layers.Dense(n_class, activation='softmax')
+        ])
+    except ValueError:
+        model_ = tf.keras.Sequential([base_model_,
+                                     tf.keras.layers.Flatten(),
+                                     tf.keras.layers.Dense(n_class, activation='softmax')
+        ])
 
     model_.compile(optimizer=optimizer, loss=loss, metrics=metrics)
 
